"use strict";
var core_1 = require("@angular/core");
var platform_browser_1 = require("@angular/platform-browser");
var core_2 = require("@angular/core");
var core_3 = require("@angular/core");
var common_1 = require("@angular/common");
//import {HammerGesturesPluginCommon} from "@angular//platform-browser/src/dom/events/hammer_common";
var core_4 = require('@angular/core');
var utilities_1 = require("../../utilities");
var pipes_1 = require("../../pipes");
var CarouselItem = (function () {
    function CarouselItem(change, _sanitizer, _renderer, element) {
        this.change = change;
        this._sanitizer = _sanitizer;
        this._renderer = _renderer;
        this.id = -1;
        this.void = null; // hack for aot
        this.zIndex = 1;
        this.imageHeight = 0;
        this.imageWidth = 0;
        this.delay = true;
        this.supportedTransform = utilities_1.AnimationUtils.getSupportedTransform();
        // uncomment for debugging ios8 safari
        //supportedTransform = "WebkitTransform";
        this.ignoreDelay = false;
        this._state = "void";
        this.element = element.nativeElement;
    }
    Object.defineProperty(CarouselItem.prototype, "backgroundImage", {
        get: function () {
            var _this = this;
            //console.log("get backgroundImage", this);
            if (this.delay && this.id > -1) {
                var delayTime = 10;
                if (this.id != 0)
                    delayTime = 500 + (Math.random() * 2000);
                setTimeout(function () {
                    _this.delay = false;
                    _this.change.markForCheck();
                }, delayTime);
            }
            if ((!this.ignoreDelay && this.delay) || !this.image || this.state == "void")
                return "none";
            return "url('" + this.image + "')";
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CarouselItem.prototype, "state", {
        get: function () {
            return this._state;
        },
        set: function (val) {
            var _this = this;
            this._state = val;
            setTimeout(function () {
                _this.change.markForCheck();
            }, 1);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CarouselItem.prototype, "isActive", {
        get: function () { return this.state == "inright" || this.state == "inleft"; },
        enumerable: true,
        configurable: true
    });
    CarouselItem.prototype.ngAfterViewInit = function () {
        if (this.supportedTransform == "WebkitTransform")
            this.supportedTransform = "";
        if (!this.supportedTransform)
            this._renderer.setElementClass(this.element, "legacy", true);
    };
    CarouselItem.prototype.getDimensions = function () {
        if (this.image && this.imageHeight == 0) {
            var image = new Image();
            image.src = this.image;
            this.imageHeight = image.height;
            this.imageWidth = image.width;
            image = undefined;
        }
        return { height: this.imageHeight, width: this.imageWidth };
    };
    CarouselItem.decorators = [
        { type: core_1.Component, args: [{
                    selector: ".carousel-item",
                    changeDetection: core_3.ChangeDetectionStrategy.OnPush,
                    template: "\n        <div *ngIf=\"supportedTransform\" [@slide]=\"state\" class=\"item-content\"\n            [style.background-image]=\"backgroundImage | safeStyle\">\n            <ng-content select=\".carousel-caption\"></ng-content>\n        </div>\n        <div *ngIf=\"!supportedTransform\" class=\"item-content\"\n            [style.z-index]=\"zIndex\"\n            [style.display]=\"isActive ? 'block' : 'none'\"\n            [style.background-image]=\"backgroundImage | safeStyle\">\n            <ng-content select=\".carousel-caption\"></ng-content>\n        </div>\n    ",
                    animations: [
                        core_4.trigger("slide", [
                            core_4.state("outright", core_4.style({
                                transform: "translate(100%,0)"
                            })),
                            core_4.state("inright, inleft", core_4.style({
                                transform: "translate(0,0)"
                            })),
                            core_4.state("outleft", core_4.style({
                                transform: "translate(-100%, 0)"
                            })),
                            core_4.state("void", core_4.style({
                                transform: "translate(100%,0)"
                            })),
                            core_4.transition("* => outright, * => outleft", [
                                core_4.style({ transform: "translate(0,0)" }),
                                core_4.animate("300ms ease"),
                            ]),
                            core_4.transition("* => inright", [
                                core_4.style({ transform: "translate(-100%,0)" }),
                                core_4.animate("300ms ease"),
                            ]),
                            core_4.transition("* => inleft", [
                                core_4.style({ transform: "translate(+100%,0)" }),
                                core_4.animate("300ms ease"),
                            ]),
                            core_4.transition("* => void", [
                                core_4.style({ display: "none" })
                            ])
                        ])
                    ]
                },] },
    ];
    /** @nocollapse */
    CarouselItem.ctorParameters = [
        { type: core_3.ChangeDetectorRef, },
        { type: platform_browser_1.DomSanitizer, },
        { type: core_1.Renderer, },
        { type: core_2.ElementRef, },
    ];
    CarouselItem.propDecorators = {
        'ignoreDelay': [{ type: core_3.Input },],
        'image': [{ type: core_3.Input },],
    };
    return CarouselItem;
}());
exports.CarouselItem = CarouselItem;
var Carousel = (function () {
    function Carousel(_change, element) {
        this._change = _change;
        this.hammerInitialized = false;
        this.items = [];
        this.direction = "left";
        this._activeIndex = 0;
        this._intervalRef = null;
        this.height = 300;
        this.innerHeight = 0;
        this.delayLoading = false;
        this.panDirection = 0; // 1 left -1 right
        this.lastPanOffset = 0;
        this.element = element.nativeElement;
    }
    Object.defineProperty(Carousel.prototype, "activeIndex", {
        get: function () { return this._activeIndex; },
        set: function (val) {
            if (this.items.length == 0) {
                this._activeIndex = -1;
                return;
            }
            this._activeIndex = val;
            for (var i in this.items) {
                var itemIndex = parseInt(i);
                if (i == val.toString())
                    this.items[i].zIndex = 10;
                else
                    this.items[i].zIndex = 1;
                if (i == val.toString())
                    this.items[i].state = "in" + this.direction;
                else if (this.direction == "right" && itemIndex == this.getRelativeIndex(1))
                    this.items[i].state = "outright";
                else if (this.direction == "left" && itemIndex == this.getRelativeIndex(-1))
                    this.items[i].state = "outleft";
                else
                    this.items[i].state = "void";
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Carousel.prototype, "interval", {
        set: function (val) {
            var _this = this;
            if (this._intervalRef != null) {
                clearInterval(this._intervalRef);
                this._intervalRef = null;
            }
            if (val > 0)
                setInterval(function () { _this.next(); }, val);
        },
        enumerable: true,
        configurable: true
    });
    Carousel.prototype.ngAfterContentInit = function () {
        var _this = this;
        this.itemQuery.changes.subscribe(function () { return _this.registerItems(); });
        this.registerItems();
        this.updateInnerHeight();
    };
    /*ngAfterContentChecked(): void {
        this.updateInnerHeight();
    }*/
    Carousel.prototype.ngAfterViewInit = function () {
        var _this = this;
        if (!this.hammerInitialized && typeof Hammer !== "undefined") {
            var hammer = new Hammer(this.element);
            hammer.on('swiperight', function (ev) {
                _this.prev();
            });
            hammer.on('swipeleft', function (ev) {
                _this.next();
            });
            /*hammer.on('pan', (ev) => {
                this.pan(ev);
            });
            hammer.on('panleft', (ev) => {
                this.panleft(ev);
            });
            hammer.on('panright', (ev) => {
                this.panright(ev);
            });*/
            this.hammerInitialized = true;
        }
    };
    Carousel.prototype.ngOnDestroy = function () {
        if (this._intervalRef != null) {
            clearInterval(this._intervalRef);
            this._intervalRef = null;
        }
    };
    Carousel.prototype.registerItems = function () {
        this.items = [];
        if (this.itemQuery.length == 0)
            return;
        var itemArray = this.itemQuery.toArray();
        for (var i in itemArray) {
            itemArray[i].id = i;
            itemArray[i].delay = this.delayLoading;
        }
        this.items = this.itemQuery.toArray();
        this.activeIndex =
            this.items.reduce(function (prev, current, index) {
                if (prev != -1 && current.isActive || !current.isActive) {
                    return prev;
                }
                else
                    return index;
            }, -1);
        if (this.activeIndex == -1)
            this.activeIndex = 0;
        var _loop_1 = function(i) {
            setTimeout(function () {
                itemArray[i].change.markForCheck();
            }, 1);
        };
        for (var i in itemArray) {
            _loop_1(i);
        }
        this._change.markForCheck();
        this.updateInnerHeight();
    };
    Carousel.prototype.updateInnerHeight = function () {
        var _this = this;
        if (this.height > 0) {
            this.innerHeight = this.height;
            return;
        }
        setTimeout(function () {
            var dimensions = _this.items[_this.activeIndex].getDimensions();
            var widthModifier = _this.element.querySelector(".carousel-inner")
                .getBoundingClientRect().width / dimensions.width;
            var newHeight = dimensions.height * widthModifier;
            _this.innerHeight = newHeight;
            if (_this.innerHeight < 1)
                _this.innerHeight = 250;
            _this._change.markForCheck();
        }, 1);
    };
    Carousel.prototype.getRelativeItem = function (rel) {
        if (this.items.length == 1)
            return this.items[0];
        return this.items[this.getRelativeIndex(rel)];
    };
    Carousel.prototype.getRelativeIndex = function (rel) {
        var target = this.activeIndex + rel;
        if (this.items.length == 0)
            return null;
        if (target < 0)
            target = this.items.length - 1;
        else if (target > (this.items.length - 1))
            target = 0;
        return target;
    };
    Carousel.prototype.navigateTo = function (item) {
        var index = this.items.indexOf(item);
        if (index > this.activeIndex)
            this.next(item);
        else
            this.prev(item);
    };
    Carousel.prototype.prev = function (item) {
        if (item === void 0) { item = null; }
        if (this.items.length < 2)
            return;
        this.direction = "right";
        this.activeIndex = this.getRelativeIndex(-1);
        this.updateInnerHeight();
        this._change.markForCheck();
    };
    Carousel.prototype.next = function (item) {
        if (item === void 0) { item = null; }
        if (this.items.length < 2)
            return;
        this.direction = "left";
        this.activeIndex = this.getRelativeIndex(1);
        this.updateInnerHeight();
        this._change.markForCheck();
    };
    Carousel.prototype.swipeleft = function () {
        if (this.panDirection == 0)
            this.next();
    };
    Carousel.prototype.swiperight = function () {
        if (this.panDirection == 0)
            this.prev();
    };
    /*panleft(event: any): void {
        if (this.panDirection == 0)
            this.panDirection = 1;
    }

    panright(event: any): void {
        if (this.panDirection == 0)
            this.panDirection = -1;
    }

    pan(event: any): void {
        event.preventDefault();

        if (this.panDirection == 0 || event.deltaX == 0)
            return;

        var current = this.getRelativeItem(0);
        var next = this.getRelativeItem(this.panDirection);
        var width = current.element.clientWidth;
        var offset = this.lastPanOffset = ((100 / width) * event.deltaX);
        var nextOffset = (100 - Math.abs(offset)) * (offset / Math.abs(offset)) * -1;

        current.translate(offset);
        next.translate(nextOffset);
    }

    panend(event: any): void {
        if (this.lastPanOffset == 0)
            return;

        var current = this.getRelativeItem(0);
        var next = this.getRelativeItem(this.panDirection);
        var offset = this.lastPanOffset;
        var nextOffset = (100 - Math.abs(offset)) * (offset / Math.abs(offset)) * -1;

        if (Math.abs(this.lastPanOffset) < 50) {
            current.slide(this.lastPanOffset, 0);
            next.slide(nextOffset, 100 * this.panDirection);
        } else {
            current.slide(this.lastPanOffset, 100 * this.panDirection);
            this.animation = next.slide(nextOffset, 0)
                .then(() => {
                    this.animation = null;
                    this.activeIndex = this.getRelativeIndex(this.panDirection);
                });
        }

        this.lastPanOffset = 0;
    }*/
    Carousel.decorators = [
        { type: core_1.Component, args: [{
                    selector: "carousel",
                    templateUrl: "Carousel.html",
                    encapsulation: core_1.ViewEncapsulation.None,
                    styleUrls: ["Carousel.css"],
                    changeDetection: core_3.ChangeDetectionStrategy.OnPush
                },] },
    ];
    /** @nocollapse */
    Carousel.ctorParameters = [
        { type: core_3.ChangeDetectorRef, },
        { type: core_2.ElementRef, },
    ];
    Carousel.propDecorators = {
        'interval': [{ type: core_3.Input },],
        'height': [{ type: core_3.Input },],
        'delayLoading': [{ type: core_3.Input },],
        'itemQuery': [{ type: core_2.ContentChildren, args: [CarouselItem,] },],
    };
    return Carousel;
}());
exports.Carousel = Carousel;
exports.carouselDirectives = [Carousel, CarouselItem];
var FuiCarouselModule = (function () {
    function FuiCarouselModule() {
    }
    FuiCarouselModule.decorators = [
        { type: core_1.NgModule, args: [{
                    imports: [common_1.CommonModule, pipes_1.FuiSafePipeModule],
                    declarations: exports.carouselDirectives,
                    exports: exports.carouselDirectives
                },] },
    ];
    /** @nocollapse */
    FuiCarouselModule.ctorParameters = [];
    return FuiCarouselModule;
}());
exports.FuiCarouselModule = FuiCarouselModule;
//# sourceMappingURL=Carousel.js.map