"use strict";
var core_1 = require('@angular/core');
var core_2 = require('@angular/core');
var DatePickerField_1 = require("./DatePickerField");
var InfiniteScroller_1 = require("../InfiniteScroller/InfiniteScroller");
var utilities_1 = require("../../utilities");
var DatePicker = (function () {
    function DatePicker(changeDetector, renderer) {
        var _this = this;
        this._minDate = new Date(1900, 0, 1);
        this._maxDate = new Date(2200, 0, 1);
        this.calendarDateFilter = function (d) { return _this.dateFilter(d, "start"); };
        this.valueChange = new core_2.EventEmitter();
        this.calendarDisplayed = false;
        this.calendarX = "5%";
        this.calendarY = "5%";
        this.calendarHeight = window.innerWidth <= 480 || window.outerWidth <= 480 ? "auto" : "300px";
        this.calendarMonths = [];
        this._preGenMonths = 2;
        this.initialScroll = true;
        this.changeDetector = changeDetector;
        this.renderer = renderer;
        this.generateMonths();
    }
    Object.defineProperty(DatePicker.prototype, "minDate", {
        get: function () { return this._minDate; },
        set: function (value) {
            this._minDate = utilities_1.DateUtils.handleDateInput(value);
        },
        enumerable: true,
        configurable: true
    });
    ;
    Object.defineProperty(DatePicker.prototype, "maxDate", {
        get: function () { return this._maxDate; },
        set: function (value) {
            this._maxDate = utilities_1.DateUtils.handleDateInput(value);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DatePicker.prototype, "value", {
        set: function (value) {
            this._selectedDate = utilities_1.DateUtils.handleDateInput(value);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DatePicker.prototype, "inputDate", {
        get: function () {
            return this.dateField != null ? this.dateField.value : "";
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DatePicker.prototype, "selectedDate", {
        get: function () { return this._selectedDate; },
        set: function (value) {
            this._selectedDate = value;
            if (this.dateField != null && this.dateField.date.getTime() != value.getTime())
                this.dateField.date = value;
            this.valueChange.next(this.selectedDate);
            this.hideCalendar();
        },
        enumerable: true,
        configurable: true
    });
    ;
    DatePicker.prototype.ngOnInit = function () {
        this.scrollerReset();
    };
    DatePicker.prototype.ngAfterContentInit = function () {
        var _this = this;
        if (this.dateField == undefined)
            throw "Fuel-UI Error: DatePicker missing date field";
        var parsedDate = utilities_1.DateUtils.handleDateInput(this.dateField.value);
        if (this.dateField.value.length > 0 && utilities_1.DateUtils.isValidDate(parsedDate))
            this.selectedDate = parsedDate;
        this.dateField.select
            .subscribe(function (event) {
            _this.showCalendar(event);
        });
        /* removed due to binding issues in FF
        this.dateField.dateChange
            .subscribe((date: Date) => {
                if(date.getTime() != this.selectedDate.getTime())
                    this.selectedDate = date;
            });*/
        this.dateFieldIcons.map(function (i) {
            i.selectEvent.subscribe(function (event) {
                _this.showCalendar(event);
            });
        });
        this.generateMonths();
    };
    DatePicker.prototype.generateMonths = function () {
        var currentDate = utilities_1.DateUtils.isValidDate(this.selectedDate) ? this.selectedDate : new Date();
        var monthOffset = this._minDate.getMonth() >= currentDate.getMonth() ? 1 : 0;
        this.calendarMonths = [
            new Date(currentDate.getFullYear(), currentDate.getMonth() + monthOffset - 1),
            new Date(currentDate.getFullYear(), currentDate.getMonth() + monthOffset)
        ];
        for (var i = 0; i < this._preGenMonths; i++) {
            var earliestDate = this.calendarMonths[0];
            var latestDate = this.calendarMonths[this.calendarMonths.length - 1];
            if (this.canPrevMonth)
                this.calendarMonths.unshift(new Date(earliestDate.getFullYear(), earliestDate.getMonth() - 1));
            if (this.canNextMonth)
                this.calendarMonths.push(new Date(latestDate.getFullYear(), latestDate.getMonth() + 1));
        }
    };
    DatePicker.prototype.scrollerReset = function () {
        var _this = this;
        setTimeout(function () {
            var currentDate = _this.selectedDate != null ? _this.selectedDate : new Date();
            if (_this.calendarScroller == null)
                return;
            var scrollToMonth = _this.calendarMonths.findIndex(function (m) {
                return m.getFullYear() == currentDate.getFullYear()
                    && m.getMonth() == currentDate.getMonth();
            });
            if (_this.initialScroll) {
                _this.initialScroll = false;
                _this.calendarScroller.container.scrollTop =
                    _this.calendarScroller.itemQuery.toArray()[scrollToMonth]
                        .element.offsetTop - 20;
            }
            _this.calendarScroller.scrollToIndex(scrollToMonth);
        }, 1);
    };
    DatePicker.prototype.toggleCalendar = function (event) {
        if (!this.calendarDisplayed)
            this.showCalendar(event);
        else
            this.hideCalendar();
    };
    DatePicker.prototype.showCalendar = function (event) {
        if (event != null && !utilities_1.MobileDetection.isAny()) {
            var clickedTarget = event.target ? event.target.parentElement : event.srcElement.parentElement;
            if (clickedTarget.classList.contains("input-group-addon"))
                clickedTarget = clickedTarget.parentElement;
            this.calendarX = clickedTarget.offsetLeft + "px";
            if (screen.height - clickedTarget.getBoundingClientRect().bottom <= 500) {
                this.calendarY = (clickedTarget.offsetTop - 300) + "px";
            }
            else {
                this.calendarY = clickedTarget.offsetTop + "px";
            }
        }
        else if (utilities_1.MobileDetection.isAny()) {
            this.calendarX = "5%";
            this.calendarY = "5%";
        }
        this.scrollerReset();
        this.changeDetector.markForCheck();
        this.calendarDisplayed = true;
    };
    DatePicker.prototype.hideCalendar = function () {
        this.calendarDisplayed = false;
        this.initialScroll = true;
        this.changeDetector.markForCheck();
    };
    Object.defineProperty(DatePicker.prototype, "canPrevMonth", {
        get: function () {
            var currentDate = this.calendarMonths[0];
            var prevDate = new Date(currentDate.getFullYear(), currentDate.getMonth() - 1);
            var compareDate = new Date(this._minDate.getFullYear(), this._minDate.getMonth());
            return prevDate >= compareDate;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DatePicker.prototype, "canNextMonth", {
        get: function () {
            var currentDate = this.calendarMonths[this.calendarMonths.length - 1];
            var nextDate = new Date(currentDate.getFullYear(), currentDate.getMonth() + 1);
            var compareDate = new Date(this._maxDate.getFullYear(), this._maxDate.getMonth());
            return nextDate <= compareDate;
        },
        enumerable: true,
        configurable: true
    });
    DatePicker.prototype.disablePrev = function () {
        return this.calendarScroller ? this.calendarScroller.isTop() : false;
    };
    DatePicker.prototype.disableNext = function () {
        return this.calendarScroller ? this.calendarScroller.isBottom() : false;
    };
    DatePicker.prototype.scrollPrevMonth = function () {
        var _this = this;
        if (this.calendarScroller.topIndex == 0)
            this.addPrevMonth();
        setTimeout(function () {
            _this.calendarScroller.scrollToIndex(_this.calendarScroller.topIndex - 1);
        }, 10);
    };
    DatePicker.prototype.scrollNextMonth = function () {
        var _this = this;
        setTimeout(function () {
            _this.calendarScroller.scrollToIndex(_this.calendarScroller.topIndex + 1);
        }, 10);
    };
    DatePicker.prototype.addNextMonth = function () {
        if (!this.canNextMonth)
            return;
        var lastMonth = this.calendarMonths[this.calendarMonths.length - 1];
        var nextMonth = new Date(lastMonth.getFullYear(), lastMonth.getMonth() + 1);
        this.calendarMonths.push(nextMonth);
        this.changeDetector.markForCheck();
    };
    DatePicker.prototype.addPrevMonth = function () {
        if (!this.canPrevMonth)
            return;
        var firstMonth = this.calendarMonths[0];
        var prevMonth = new Date(firstMonth.getFullYear(), firstMonth.getMonth() - 1);
        this.calendarMonths.unshift(prevMonth);
        this.changeDetector.markForCheck();
    };
    DatePicker.decorators = [
        { type: core_1.Component, args: [{
                    selector: "date-picker",
                    styleUrls: ["DatePicker.css"],
                    templateUrl: "DatePicker.html",
                    encapsulation: core_1.ViewEncapsulation.None,
                    changeDetection: core_1.ChangeDetectionStrategy.OnPush
                },] },
    ];
    /** @nocollapse */
    DatePicker.ctorParameters = [
        { type: core_1.ChangeDetectorRef, },
        { type: core_1.Renderer, },
    ];
    DatePicker.propDecorators = {
        'minDate': [{ type: core_2.Input },],
        'maxDate': [{ type: core_2.Input },],
        'dateFilter': [{ type: core_2.Input },],
        'valueChange': [{ type: core_2.Output },],
        'value': [{ type: core_2.Input },],
        'calendarScroller': [{ type: core_2.ViewChild, args: [InfiniteScroller_1.InfiniteScroller,] },],
        'dateField': [{ type: core_2.ContentChild, args: [DatePickerField_1.DatePickerField,] },],
        'dateFieldIcons': [{ type: core_2.ContentChildren, args: [DatePickerField_1.DatePickerFieldStyler,] },],
    };
    return DatePicker;
}());
exports.DatePicker = DatePicker;
//# sourceMappingURL=DatePicker.js.map