"use strict";
var core_1 = require("@angular/core");
var core_2 = require("@angular/core");
var utilities_1 = require("../../utilities");
var DatePickerCalendar = (function () {
    function DatePickerCalendar() {
        this.selectedDateChange = new core_2.EventEmitter();
        this.dateTarget = null;
        this.showMonth = true;
        this.today = new Date();
        this.today.setHours(0, 0, 0);
    }
    DatePickerCalendar.prototype.ngOnInit = function () {
        this.buildWeeks(this.currentMonth || new Date());
    };
    DatePickerCalendar.prototype.checkSelectable = function (date) {
        var dateNumber = parseInt(date);
        if (isNaN(dateNumber))
            return false;
        var compareDate = new Date(this.currentMonth.getFullYear(), this.currentMonth.getMonth(), dateNumber);
        if (typeof this.dateFilter == "function" && !this.dateFilter(compareDate))
            return false;
        return compareDate >= this.minDate && compareDate <= this.maxDate;
    };
    DatePickerCalendar.prototype.checkSelectedDate = function (date) {
        if (this.selectedDate == null)
            return false;
        if (this.startDate != null && this.endDate != null) {
            var compareDate = new Date(this.currentMonth.getFullYear(), this.currentMonth.getMonth(), parseInt(date));
            return compareDate >= this.startDate && compareDate <= this.endDate;
        }
        return this.selectedDate.getFullYear() == this.currentMonth.getFullYear()
            && this.selectedDate.getMonth() == this.currentMonth.getMonth()
            && this.selectedDate.getDate().toString() == date;
    };
    DatePickerCalendar.prototype.checkToday = function (date) {
        return this.today.getFullYear() == this.currentMonth.getFullYear()
            && this.today.getMonth() == this.currentMonth.getMonth()
            && this.today.getDate() == parseInt(date);
    };
    DatePickerCalendar.prototype.checkStartDate = function (date) {
        if (this.endDate == null || !utilities_1.DateUtils.isValidDate(this.startDate) || !utilities_1.DateUtils.isValidDate(this.endDate))
            return false;
        if (this.startDate.getFullYear() == this.endDate.getFullYear()
            && this.startDate.getMonth() == this.endDate.getMonth()
            && this.startDate.getDate().toString() == this.endDate.getDate().toString())
            return false;
        return this.startDate.getFullYear() == this.currentMonth.getFullYear()
            && this.startDate.getMonth() == this.currentMonth.getMonth()
            && this.startDate.getDate().toString() == date;
    };
    DatePickerCalendar.prototype.checkEndDate = function (date) {
        if (this.endDate == null || !utilities_1.DateUtils.isValidDate(this.startDate) || !utilities_1.DateUtils.isValidDate(this.endDate))
            return false;
        if (this.startDate.getFullYear() == this.endDate.getFullYear()
            && this.startDate.getMonth() == this.endDate.getMonth()
            && this.startDate.getDate().toString() == this.endDate.getDate().toString())
            return false;
        return this.endDate.getFullYear() == this.currentMonth.getFullYear()
            && this.endDate.getMonth() == this.currentMonth.getMonth()
            && this.endDate.getDate().toString() == date;
    };
    DatePickerCalendar.prototype.selectDate = function (date) {
        if (!this.checkSelectable(date))
            return;
        var dateNumber = parseInt(date);
        this.selectedDate = new Date(this.currentMonth.getFullYear(), this.currentMonth.getMonth(), dateNumber);
        this.selectedDateChange.next(this.selectedDate);
    };
    DatePickerCalendar.prototype.buildWeeks = function (date) {
        this.currentMonth = date;
        var currentDay = new Date(this.currentMonth.toDateString());
        currentDay.setDate(1);
        currentDay.setDate(currentDay.getDate() - currentDay.getDay());
        var lastDay = new Date(this.currentMonth.getFullYear(), this.currentMonth.getMonth() + 1, 0);
        lastDay.setDate(lastDay.getDate() + (6 - lastDay.getDay()));
        this.weeks = [];
        var currentWeek = [];
        while (currentDay <= lastDay) {
            if (currentDay.getMonth() == this.currentMonth.getMonth())
                currentWeek.push(currentDay.getDate().toLocaleString());
            else
                currentWeek.push("");
            currentDay.setDate(currentDay.getDate() + 1);
            if (currentDay.getDay() == 0) {
                this.weeks.push(currentWeek);
                currentWeek = [];
            }
        }
    };
    DatePickerCalendar.decorators = [
        { type: core_1.Component, args: [{
                    selector: "date-picker-calendar",
                    templateUrl: "DatePickerCalendar.html",
                    styleUrls: ["DatePickerCalendar.css"],
                    encapsulation: core_1.ViewEncapsulation.None
                },] },
    ];
    /** @nocollapse */
    DatePickerCalendar.ctorParameters = [];
    DatePickerCalendar.propDecorators = {
        'currentMonth': [{ type: core_2.Input },],
        'selectedDate': [{ type: core_2.Input },],
        'selectedDateChange': [{ type: core_2.Output },],
        'dateTarget': [{ type: core_2.Input },],
        'startDate': [{ type: core_2.Input },],
        'endDate': [{ type: core_2.Input },],
        'minDate': [{ type: core_2.Input },],
        'maxDate': [{ type: core_2.Input },],
        'dateFilter': [{ type: core_2.Input },],
        'showMonth': [{ type: core_2.Input },],
    };
    return DatePickerCalendar;
}());
exports.DatePickerCalendar = DatePickerCalendar;
//# sourceMappingURL=DatePickerCalendar.js.map