"use strict";
var core_1 = require("@angular/core");
var utilities_1 = require("../../utilities");
var DatePickerField = (function () {
    function DatePickerField() {
        this._date = new Date();
        this._value = "";
        this.valueChange = new core_1.EventEmitter();
        this.ngModelChange = new core_1.EventEmitter();
        this.dateChange = new core_1.EventEmitter();
        this.select = new core_1.EventEmitter();
        this.readonly = true;
    }
    Object.defineProperty(DatePickerField.prototype, "value", {
        get: function () { return this._value; },
        set: function (value) {
            if (value == this._value)
                return;
            this._value = value;
            this._date = utilities_1.DateUtils.handleDateInput(value);
            this.valueChange.next(value);
            this.ngModelChange.next(value);
            this.dateChange.next(this._date);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DatePickerField.prototype, "ngModel", {
        set: function (value) {
            this.value = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DatePickerField.prototype, "date", {
        get: function () { return this._date; },
        set: function (date) {
            if (date.getTime() == this._date.getTime())
                return;
            this._date = date;
            this._value = date.toLocaleDateString();
            this.dateChange.next(date);
            this.ngModelChange.next(this._value);
            this.valueChange.next(this._value);
        },
        enumerable: true,
        configurable: true
    });
    DatePickerField.prototype.inputChange = function (value) {
        this.value = value;
    };
    DatePickerField.prototype.focused = function (event) {
        this.select.next(event);
    };
    DatePickerField.prototype.selected = function (event) {
        this.select.next(event);
    };
    DatePickerField.prototype.ngOnInit = function () {
        this.date = utilities_1.DateUtils.handleDateInput(this.value);
    };
    DatePickerField.decorators = [
        { type: core_1.Directive, args: [{
                    selector: "[dateField],.date-field"
                },] },
    ];
    /** @nocollapse */
    DatePickerField.ctorParameters = [];
    DatePickerField.propDecorators = {
        '_value': [{ type: core_1.HostBinding, args: ["value",] },],
        'value': [{ type: core_1.Input },],
        'valueChange': [{ type: core_1.Output },],
        'ngModel': [{ type: core_1.Input },],
        'ngModelChange': [{ type: core_1.Output },],
        'date': [{ type: core_1.Input },],
        'dateChange': [{ type: core_1.Output },],
        'inputChange': [{ type: core_1.HostListener, args: ["input", ["$event.target.value"],] },],
        'focused': [{ type: core_1.HostListener, args: ["focus", ["$event"],] },],
        'select': [{ type: core_1.Output },],
        'selected': [{ type: core_1.HostListener, args: ["click", ["$event"],] },],
        'readonly': [{ type: core_1.HostBinding, args: ["attr.readonly",] },],
    };
    return DatePickerField;
}());
exports.DatePickerField = DatePickerField;
var DatePickerFieldStyler = (function () {
    function DatePickerFieldStyler(ref) {
        this.selectEvent = new core_1.EventEmitter();
        this.element = ref.nativeElement;
    }
    DatePickerFieldStyler.prototype.isStartDate = function () {
        var startDateField = this.element.querySelector("input[startDateField]");
        return typeof startDateField !== "undefined" && startDateField !== null;
    };
    DatePickerFieldStyler.prototype.isEndDate = function () {
        var endDateField = this.element.querySelector("input[endDateField]");
        return typeof endDateField !== "undefined" && endDateField !== null;
    };
    DatePickerFieldStyler.prototype.select = function (event) {
        this.selectEvent.next(event);
    };
    DatePickerFieldStyler.decorators = [
        { type: core_1.Component, args: [{
                    selector: ".date-picker-input-group",
                    template: " \n    <div class=\"input-group fuel-ui-datepicker-input-group\">\n        <ng-content></ng-content>\n        <span class=\"input-group-addon\" (click)=\"select($event)\"> \n            <i class=\"fa fa-calendar\"></i>\n        </span>\n    </div>"
                },] },
    ];
    /** @nocollapse */
    DatePickerFieldStyler.ctorParameters = [
        { type: core_1.ElementRef, },
    ];
    return DatePickerFieldStyler;
}());
exports.DatePickerFieldStyler = DatePickerFieldStyler;
//# sourceMappingURL=DatePickerField.js.map