"use strict";
var core_1 = require('@angular/core');
var common_1 = require("@angular/common");
var utilities_1 = require("../../utilities");
var ScrollItem = (function () {
    function ScrollItem(element) {
        this.element = element.nativeElement;
    }
    Object.defineProperty(ScrollItem.prototype, "height", {
        get: function () {
            return utilities_1.ElementUtils.outerHeight(this.element);
        },
        enumerable: true,
        configurable: true
    });
    ScrollItem.prototype.ngAfterViewInit = function () {
        this.element = this.element.firstElementChild;
    };
    ScrollItem.decorators = [
        { type: core_1.Directive, args: [{
                    selector: "[scroll-item],.scroll-item"
                },] },
    ];
    /** @nocollapse */
    ScrollItem.ctorParameters = [
        { type: core_1.ElementRef, },
    ];
    return ScrollItem;
}());
exports.ScrollItem = ScrollItem;
var InfiniteScroller = (function () {
    //test
    function InfiniteScroller(element) {
        this.distance = 100;
        this.height = 'auto';
        this.hideScrollbar = false;
        this.next = new core_1.EventEmitter();
        this.prev = new core_1.EventEmitter();
        this.topIndexChange = new core_1.EventEmitter();
        this.topIndex = 0;
        this.bottomIndexChange = new core_1.EventEmitter();
        this.bottomIndex = 0;
        this.lastScroll = 0;
        this.container = element.nativeElement;
    }
    InfiniteScroller.prototype.ngAfterContentInit = function () {
        var _this = this;
        this.firstItem = this.itemQuery.first;
        this.itemQuery.changes.subscribe(function () {
            _this.handleItemChanges();
        });
    };
    InfiniteScroller.prototype.ngAfterViewInit = function () {
        this.container = this.container.querySelector(".scroll-container");
        this.container.scrollTop += 1;
    };
    InfiniteScroller.prototype.handleItemChanges = function () {
        if (this.firstItem == null)
            this.firstItem = this.itemQuery.first;
        if (this.firstItem !== this.itemQuery.first) {
            this.container.scrollTop += this.itemQuery.first.height;
            this.firstItem = this.itemQuery.first;
        }
    };
    InfiniteScroller.prototype.getVisableIndicies = function () {
        var _this = this;
        var itemArray = this.itemQuery.toArray();
        var visableIndicies = itemArray
            .filter(function (i) { return _this.checkVisableItem(i); })
            .map(function (i) { return itemArray.indexOf(i); });
        if (visableIndicies.length > 1) {
            this.topIndex = visableIndicies[0];
            this.bottomIndex = visableIndicies[visableIndicies.length - 1];
            this.topIndexChange.next(this.topIndex);
            this.bottomIndexChange.next(this.bottomIndex);
        }
        else if (visableIndicies.length > 0) {
            this.topIndex = visableIndicies[0];
            this.topIndexChange.next(this.topIndex);
        }
    };
    InfiniteScroller.prototype.checkVisableItem = function (item) {
        var itemTop = item.element.offsetTop;
        var itemBottom = itemTop + utilities_1.ElementUtils.outerHeight(item.element);
        var viewTop = this.container.scrollTop + this.container.offsetTop;
        var viewBottom = viewTop + this.container.clientHeight;
        if (itemTop > viewTop && itemTop < viewBottom)
            return true;
        if (itemBottom > viewTop && itemBottom < viewBottom)
            return true;
        if (itemTop < viewTop && itemBottom > viewBottom)
            return true;
        return false;
    };
    InfiniteScroller.prototype.doscroll = function (event) {
        var target = (typeof event.srcElement === 'undefined' ? event.target : event.srcElement);
        var targetRect = target.getBoundingClientRect();
        var bottomPosition = target.scrollHeight - (target.scrollTop + targetRect.height);
        var scrollDown = target.scrollTop > this.lastScroll;
        var saveLastScroll = this.lastScroll;
        this.lastScroll = target.scrollTop;
        if (scrollDown && target.scrollHeight - (target.scrollTop + targetRect.height) <= this.distance * 2) {
            this.next.emit(null);
            if (target.scrollHeight - target.scrollTop === target.clientHeight) {
                target.scrollTop -= 10;
            }
        }
        else if (!scrollDown && target.scrollTop <= this.distance * 2) {
            this.prev.emit(null);
        }
        this.getVisableIndicies();
        if (target.scrollTop < 1)
            target.scrollTop = 1;
    };
    InfiniteScroller.prototype.scrollTo = function (position, animate) {
        if (animate === void 0) { animate = true; }
        if (animate)
            utilities_1.ElementUtils.scrollTo(this.container, position, 400);
        else
            this.container.scrollTop = position;
    };
    InfiniteScroller.prototype.scrollToIndex = function (index, animate) {
        if (animate === void 0) { animate = true; }
        var itemArray = this.itemQuery.toArray();
        var targetIndex = 0;
        if (index > 0 && index < itemArray.length)
            targetIndex = index;
        else if (index >= itemArray.length)
            targetIndex = itemArray.length - 1;
        if (targetIndex < 0)
            targetIndex = 0;
        var target = this.itemQuery.toArray()[targetIndex];
        var targetPos = target.element.offsetTop - this.container.offsetTop;
        this.scrollTo(targetPos, animate);
    };
    InfiniteScroller.prototype.isTop = function () {
        return this.lastScroll <= 1;
    };
    InfiniteScroller.prototype.isBottom = function () {
        return (this.lastScroll + this.container.clientHeight) >= this.container.scrollHeight - 10;
    };
    InfiniteScroller.decorators = [
        { type: core_1.Component, args: [{
                    selector: "infinite-scroller",
                    template: " \n        <!--<div class=\"scroll-outer\" [class.hide-scrollbar]=\"hideScrollbar\">-->\n            <div class=\"scroll-container\"\n                (scroll)=\"doscroll($event)\"\n                [style.height]=\"height\">\n                <ng-content></ng-content>\n            </div>\n    ",
                    styles: ["\n        .scroll-container {\n            overflow-y: scroll;\n            overflow-x: hidden;\n            max-height: 100%;\n        }\n\n        .scroll-outer.hide-scrollbar .scroll-container {\n            margin-right: -16px;\n        }\n\n        .scroll-content {\n            overflow: auto;\n        }\n    "],
                    encapsulation: core_1.ViewEncapsulation.None
                },] },
    ];
    /** @nocollapse */
    InfiniteScroller.ctorParameters = [
        { type: core_1.ElementRef, },
    ];
    InfiniteScroller.propDecorators = {
        'distance': [{ type: core_1.Input },],
        'height': [{ type: core_1.Input },],
        'hideScrollbar': [{ type: core_1.Input },],
        'next': [{ type: core_1.Output },],
        'prev': [{ type: core_1.Output },],
        'topIndexChange': [{ type: core_1.Output },],
        'bottomIndexChange': [{ type: core_1.Output },],
        'itemQuery': [{ type: core_1.ContentChildren, args: [ScrollItem,] },],
    };
    return InfiniteScroller;
}());
exports.InfiniteScroller = InfiniteScroller;
exports.infiniteScrollerDirectives = [
    InfiniteScroller,
    ScrollItem
];
var FuiInfiniteScrollerModule = (function () {
    function FuiInfiniteScrollerModule() {
    }
    FuiInfiniteScrollerModule.decorators = [
        { type: core_1.NgModule, args: [{
                    imports: [common_1.CommonModule],
                    declarations: exports.infiniteScrollerDirectives,
                    exports: exports.infiniteScrollerDirectives
                },] },
    ];
    /** @nocollapse */
    FuiInfiniteScrollerModule.ctorParameters = [];
    return FuiInfiniteScrollerModule;
}());
exports.FuiInfiniteScrollerModule = FuiInfiniteScrollerModule;
//# sourceMappingURL=InfiniteScroller.js.map