"use strict";
var core_1 = require('@angular/core');
var common_1 = require('@angular/common');
var noUiSlider = require("nouislider");
var Slider = (function () {
    function Slider(_element) {
        this._element = _element;
        this.background = "#E24932";
        this.height = "";
        this.width = "";
        this.orientation = "horizontal";
        this.direction = "ltr";
        this.behavior = "tap";
        this.pips = 5;
        this.pipDensity = 5;
        this.step = 1;
        this.decimals = 0;
        this.minValue = 0;
        this.maxValue = 100;
        this.margin = 10;
        this.value = 0;
        this.secondValue = null;
        this.debounceTime = 150;
        this.handleHeight = "";
        this.valueChange = new core_1.EventEmitter();
        this.secondValueChange = new core_1.EventEmitter();
        this.timeout = null;
    }
    Slider.prototype.update = function (val) {
        this.value = parseInt(val[0]);
        this.secondValue = val.length > 1 ? parseInt(val[1]) : null;
        this.valueChange.next(this.value);
        this.secondValueChange.next(this.secondValue);
        this.timeout = null;
    };
    ;
    Slider.prototype.ngAfterViewInit = function () {
        var _this = this;
        this._sliderElement = this._element.nativeElement.children[0];
        if (this.orientation == 'vertical')
            this._sliderElement.style.height = this.height.length > 0
                ? this.height
                : "200px";
        if (this.orientation == 'horizontal') {
            this._sliderElement.style.width = this.width.length > 0
                ? this.width
                : null; //full width
            if (this.height.length > 0)
                this._sliderElement.style.height = this.height;
        }
        setTimeout(function () {
            if (_this.handleHeight.length > 0) {
                var handles = _this._sliderElement.childNodes[0].getElementsByClassName("noUi-handle");
                for (var i = 0; i < handles.length; i++) {
                    handles[i].style.height = _this.handleHeight;
                }
            }
        }, 500);
        this._slider = noUiSlider.create(this._sliderElement, {
            start: this.secondValue != null ? [this.value, this.secondValue] : this.value,
            step: parseInt(this.step.toString()),
            margin: this.margin,
            connect: this.secondValue != null ? true : 'lower',
            direction: this.direction,
            orientation: this.orientation,
            behaviour: this.behavior,
            range: {
                'min': parseInt(this.minValue.toString()),
                'max': parseInt(this.maxValue.toString())
            },
            pips: {
                mode: 'count',
                values: this.pips,
                density: this.pipDensity
            },
            format: {
                to: function (value) {
                    return parseFloat(value).toFixed(_this.decimals);
                },
                from: function (value) {
                    return parseFloat(value).toFixed(_this.decimals);
                }
            }
        });
        if (!this._element.nativeElement.disabled) {
            var noUI = this._element.nativeElement.getElementsByClassName('noUi-connect');
            //convert HTMLCollection to array to loop
            [].slice.call(noUI).forEach(function (el) {
                el.style.background = _this.background;
            });
        }
        this._sliderElement.noUiSlider.on('slide', function (val) {
            if (_this.timeout)
                clearTimeout(_this.timeout);
            _this.timeout = setTimeout(function () {
                _this.update(val);
            }, _this.debounceTime);
        });
        this._sliderElement.noUiSlider.on('end', function (val) {
            if (_this.timeout)
                clearTimeout(_this.timeout);
            _this.update(val);
        });
    };
    Slider.prototype.ngOnChanges = function (changes) {
        if (this._sliderElement && typeof changes.value !== 'undefined')
            this._sliderElement.noUiSlider.set([changes.value.currentValue, this.secondValue]);
        if (this._sliderElement && typeof changes.secondValue !== 'undefined')
            this._sliderElement.noUiSlider.set([this.value, changes.secondValue.currentValue]);
    };
    Slider.decorators = [
        { type: core_1.Component, args: [{
                    selector: "slider",
                    templateUrl: 'Slider.html',
                    styleUrls: ["Slider.css"],
                    encapsulation: core_1.ViewEncapsulation.None
                },] },
    ];
    /** @nocollapse */
    Slider.ctorParameters = [
        { type: core_1.ElementRef, },
    ];
    Slider.propDecorators = {
        'background': [{ type: core_1.Input },],
        'height': [{ type: core_1.Input },],
        'width': [{ type: core_1.Input },],
        'orientation': [{ type: core_1.Input },],
        'direction': [{ type: core_1.Input },],
        'behavior': [{ type: core_1.Input },],
        'pips': [{ type: core_1.Input },],
        'pipDensity': [{ type: core_1.Input },],
        'step': [{ type: core_1.Input },],
        'decimals': [{ type: core_1.Input },],
        'minValue': [{ type: core_1.Input },],
        'maxValue': [{ type: core_1.Input },],
        'margin': [{ type: core_1.Input },],
        'value': [{ type: core_1.Input },],
        'secondValue': [{ type: core_1.Input },],
        'debounceTime': [{ type: core_1.Input },],
        'handleHeight': [{ type: core_1.Input },],
        'valueChange': [{ type: core_1.Output },],
        'secondValueChange': [{ type: core_1.Output },],
    };
    return Slider;
}());
exports.Slider = Slider;
var FuiSliderModule = (function () {
    function FuiSliderModule() {
    }
    FuiSliderModule.decorators = [
        { type: core_1.NgModule, args: [{
                    imports: [common_1.CommonModule],
                    declarations: [Slider],
                    exports: [Slider]
                },] },
    ];
    /** @nocollapse */
    FuiSliderModule.ctorParameters = [];
    return FuiSliderModule;
}());
exports.FuiSliderModule = FuiSliderModule;
//# sourceMappingURL=Slider.js.map