"use strict";
var core_1 = require('@angular/core');
var demoUtilities_1 = require('../../utilities/demoUtilities');
var TabDemo = (function () {
    function TabDemo() {
        this.codeExample1 = "&lt;tabset&gt;\n    &lt;tab *ngFor=&quot;#theTab of tabs&quot;\n        [heading]=&quot;theTab.heading&quot;\n        [(active)]=&quot;theTab.active&quot;\n        [disabled]=&quot;theTab.disabled&quot;\n        [removable]=&quot;theTab.removable&quot;\n        (deselect)=&quot;deselectLog($event)&quot;\n        (select)=&quot;selectLog($event)&quot;\n        (remove)=&quot;removeLog($event)&quot;&gt;\n    {{theTab?.content}}\n    &lt;/tab&gt;\n&lt;/tabset&gt;\n\n&lt;tabset [vertical]=&quot;true&quot; type=&quot;pills&quot;&gt;\n    &lt;tab heading=&quot;Vertical 1&quot;&gt;Vertical content 1&lt;/tab&gt;\n    &lt;tab heading=&quot;Vertical 2&quot;&gt;Vertical content 2&lt;/tab&gt;\n&lt;/tabset&gt;";
        this.codeExample2 = "export class TabExample {\n    tabs:any[] = [\n        {heading: 'Title 1', content: 'Content 1', active: true},\n        {heading: 'Title 2', content: 'Content 2'},\n        {heading: 'Title 3', content: 'Content 3'},\n        {heading: 'Title 4', content: 'Content 4', removable: true}\n    ];\n    \n    deselectLog(tab: Tab):void {\n        console.log('Deselected:', tab.heading);\n    }\n    \n    selectLog(tab: Tab):void {\n        console.log('Selected:', tab.heading);\n    }\n    \n    removeLog(tab: Tab):void {\n        console.log('Removed:', tab.heading);\n    }\n}";
        this.tabs = [
            { heading: 'Title 1', content: 'Content 1', active: true },
            { heading: 'Title 2', content: 'Content 2' },
            { heading: 'Title 3', content: 'Content 3' },
            { heading: 'Title 4', content: 'Content 4', removable: true }
        ];
        this.tabSetAttributes = [
            new demoUtilities_1.Attribute('vertical', 'boolean', 'false', 'Displays the tabs vertically'),
            new demoUtilities_1.Attribute('type', 'string', 'tabs', 'The tab type to be displayed. Can also be "pills" to display tab headers as bubbles, commonly used when displaying tabs vertically'),
        ];
        this.tabSetAttributesColumns = demoUtilities_1.AttributeColumns;
        this.tabSetAttributesSort = demoUtilities_1.AttributesDefaultSort;
        this.tabAttributes = [
            new demoUtilities_1.Attribute('heading', 'string', 'null', 'Html of Tab\'s heading'),
            new demoUtilities_1.Attribute('active', 'boolean', 'false', 'Is currently selected and displayed'),
            new demoUtilities_1.Attribute('disabled', 'boolean', 'false', 'Makes the tab greyed out and unselectable'),
            new demoUtilities_1.Attribute('removable', 'boolean', 'false', 'Makes the tab able to be removed from the TabSet and adds an X icon to the heading that removes the tab on click')
        ];
        this.tabAttributesColumns = demoUtilities_1.AttributeColumns;
        this.tabAttributesSort = demoUtilities_1.AttributesDefaultSort;
        this.tabEvents = [
            new demoUtilities_1.Event('deselect', '$event = tab: Tab', 'Returns the Tab object when deselected'),
            new demoUtilities_1.Event('remove', '$event = tab: Tab', 'Returns the Tab object when removed'),
            new demoUtilities_1.Event('select', '$event = tab: Tab', 'Returns the Tab object when selected')
        ];
        this.tabEventsColumns = demoUtilities_1.EventColumns;
        this.tabEventsSort = demoUtilities_1.EventsDefaultSort;
    }
    TabDemo.prototype.addTab = function () {
        this.tabs.push({ heading: 'Removable Tab', content: "I'm removable", removable: true });
    };
    TabDemo.prototype.setActiveTab = function (index) {
        this.tabs[index].active = true;
    };
    ;
    TabDemo.prototype.deselectLog = function (tab) {
        console.log('Deselected:', tab.heading);
    };
    TabDemo.prototype.selectLog = function (tab) {
        console.log('Selected:', tab.heading);
    };
    TabDemo.prototype.removeLog = function (tab) {
        console.log('Removed:', tab.heading);
    };
    TabDemo.decorators = [
        { type: core_1.Component, args: [{
                    changeDetection: core_1.ChangeDetectionStrategy.OnPush,
                    templateUrl: "Tab.Demo.html"
                },] },
    ];
    /** @nocollapse */
    TabDemo.ctorParameters = [];
    return TabDemo;
}());
exports.TabDemo = TabDemo;
//# sourceMappingURL=Tab.Demo.js.map