"use strict";
var core_1 = require('@angular/core');
var TabSet = (function () {
    function TabSet() {
        this.tabs = [];
        this.classMap = {};
    }
    Object.defineProperty(TabSet.prototype, "vertical", {
        get: function () { return this._vertical; },
        set: function (value) {
            this._vertical = value;
            this.setClassMap();
        },
        enumerable: true,
        configurable: true
    });
    ;
    Object.defineProperty(TabSet.prototype, "type", {
        get: function () { return this._type; },
        set: function (value) {
            this._type = value;
            this.setClassMap();
        },
        enumerable: true,
        configurable: true
    });
    ;
    TabSet.prototype.ngOnInit = function () {
        this.type = this.type !== 'undefined' ? this.type : 'tabs';
    };
    TabSet.prototype.ngOnDestroy = function () {
        this.destroyed = true;
    };
    TabSet.prototype.addTab = function (tab) {
        this.tabs.push(tab);
        tab.active = this.tabs.length === 1 && tab.active !== false;
    };
    TabSet.prototype.removeTab = function (tab) {
        var index = this.tabs.indexOf(tab);
        if (index === -1 || this.destroyed) {
            return;
        }
        if (tab.active && this.hasAvailableTabs(index)) {
            var newActiveIndex = this.getClosestTabIndex(index);
            this.tabs[newActiveIndex].active = true;
        }
        tab.remove.next(tab);
        this.tabs.splice(index, 1);
    };
    TabSet.prototype.getClosestTabIndex = function (index) {
        var tabsLength = this.tabs.length;
        if (!tabsLength) {
            return -1;
        }
        for (var step = 1; step <= tabsLength; step += 1) {
            var prevIndex = index - step;
            var nextIndex = index + step;
            if (this.tabs[prevIndex] && !this.tabs[prevIndex].disabled) {
                return prevIndex;
            }
            if (this.tabs[nextIndex] && !this.tabs[nextIndex].disabled) {
                return nextIndex;
            }
        }
        return -1;
    };
    TabSet.prototype.hasAvailableTabs = function (index) {
        var tabsLength = this.tabs.length;
        if (!tabsLength) {
            return false;
        }
        for (var i = 0; i < tabsLength; i += 1) {
            if (!this.tabs[i].disabled && i !== index) {
                return true;
            }
        }
        return false;
    };
    TabSet.prototype.setClassMap = function () {
        this.classMap = (_a = {
                'nav-stacked': this.vertical
            },
            _a['nav-' + (this.type || 'tabs')] = true,
            _a
        );
        var _a;
    };
    TabSet.decorators = [
        { type: core_1.Component, args: [{
                    selector: 'tabset',
                    templateUrl: 'TabSet.html'
                },] },
    ];
    /** @nocollapse */
    TabSet.ctorParameters = [];
    TabSet.propDecorators = {
        'vertical': [{ type: core_1.Input },],
        'type': [{ type: core_1.Input },],
    };
    return TabSet;
}());
exports.TabSet = TabSet;
//# sourceMappingURL=TabSet.js.map