"use strict";
var core_1 = require('@angular/core');
var demoUtilities_1 = require('../../utilities/demoUtilities');
var TagDemo = (function () {
    function TagDemo() {
        this.codeExample1 = "&lt;tagset&gt;\n    &lt;tag *ngFor=&quot;#theTag of tags&quot;\n        [color]=&quot;theTag.color&quot;\n        [pill]=&quot;theTag.pill&quot;\n        [removable]=&quot;theTag.removable&quot;\n        [title]=&quot;theTag.title&quot;\n        [value]=&quot;theTag.value&quot;\n        (remove)=&quot;removeLog($event)&quot;&gt;\n    &lt;/tag&gt;\n&lt;/tagset&gt;";
        this.codeExample2 = "export class TagExample {\n    tags:any[] = [\n        {title: 'Default'},\n        {title: 'Primary', color: 'primary', pill: true, removable: true, value: 'Some great value'},\n        {title: 'Info', color: 'info', pill: true, removable: true, value: false},\n        {title: 'Success', color: 'success', pill: true, removable: true, value: 1234567890},\n        {title: 'Danger', color: 'danger', pill: false, removable: true, value: {some: 'great', value: true}},\n        {title: 'Warning', color: 'warning', pill: false, removable: true, value: true}\n    ];\n    \n    removeLog(tag: Tag):void {\n        console.log('Removed:', tag.title, '-', tag.value);\n    }\n}";
        this.valueError = false;
        this.tempTag = {
            title: 'Example Title',
            color: 'default',
            disabled: false,
            pill: true,
            removable: true,
            value: 'Some value here'
        };
        this.tags = [
            { title: 'Default' },
            { title: 'Primary', color: 'primary', pill: true, removable: true, value: 'Some great value' },
            { title: 'Info', color: 'info', pill: true, removable: true, value: false },
            { title: 'Success', color: 'success', pill: true, removable: true, value: 1234567890 },
            { title: 'Danger', color: 'danger', pill: false, removable: true, value: { some: 'great', value: true } },
            { title: 'Warning', color: 'warning', pill: false, removable: true, value: true }
        ];
        this.tagAttributes = [
            new demoUtilities_1.Attribute('color', 'string', 'default', 'Bootstrap color of the Tag. <a href="http://v4-alpha.getbootstrap.com/components/label/#contextual-variations" target="_blank">Click here for more info...</a>'),
            new demoUtilities_1.Attribute('pill', 'boolean', 'false', 'Show the Tag as a pill'),
            new demoUtilities_1.Attribute('title', 'string', 'null', 'Html of Tag\'s title'),
            new demoUtilities_1.Attribute('value', 'any', 'null', 'Value of the Tag'),
            new demoUtilities_1.Attribute('removable', 'boolean', 'false', 'Makes the tag able to be removed from the TagSet and adds an X icon to the title that removes the tag on click')
        ];
        this.tagAttributesColumns = demoUtilities_1.AttributeColumns;
        this.tagAttributesSort = demoUtilities_1.AttributesDefaultSort;
        this.tagEvents = [
            new demoUtilities_1.Event('remove', '$event = tag: Tag', 'Returns the Tag object when removed')
        ];
        this.tagEventsColumns = demoUtilities_1.EventColumns;
        this.tagEventsSort = demoUtilities_1.EventsDefaultSort;
    }
    TagDemo.prototype.clearTags = function () {
        this.tags = [];
    };
    TagDemo.prototype.addTag = function () {
        var _this = this;
        this.valueError = false;
        this.tags.forEach(function (obj, i) {
            if (_this.tempTag.value === obj.value) {
                _this.valueError = true;
            }
        });
        if (this.valueError)
            return;
        this.tags.push(JSON.parse(JSON.stringify(this.tempTag))); //make simple copy of tempTag to add
    };
    TagDemo.prototype.removeLog = function (tag) {
        var _this = this;
        console.log('Removed:', tag.title, '-', tag.value);
        try {
            this.tags.forEach(function (obj, i) {
                if (tag.value === obj.value) {
                    throw _this.tags.splice(i, 1);
                }
            });
        }
        catch (e) {
        }
    };
    TagDemo.decorators = [
        { type: core_1.Component, args: [{
                    templateUrl: "Tag.Demo.html"
                },] },
    ];
    /** @nocollapse */
    TagDemo.ctorParameters = [];
    return TagDemo;
}());
exports.TagDemo = TagDemo;
//# sourceMappingURL=Tag.Demo.js.map