"use strict";
var core_1 = require('@angular/core');
var common_1 = require('@angular/common');
var TextExpander = (function () {
    function TextExpander() {
        this.expanded = false;
        this.ellipsis = true;
        this.text = null;
        this.characters = 50;
        this.words = 0;
        this.expandText = "show more";
        this.shrinkText = "show less";
        this.expandedChange = new core_1.EventEmitter();
    }
    TextExpander.prototype.toggleExpand = function () {
        this.expanded = !this.expanded;
        this.expandedChange.next(this.expanded);
    };
    TextExpander.prototype.amountOfCharacters = function () {
        if (this.words > 0)
            return this.getCharactersUpToNumberOfWords(this.words);
        return this.characters;
    };
    TextExpander.prototype.getCharactersUpToNumberOfWords = function (words) {
        //make copy of text to remove multiple spaces between words
        var textCopy = this.text;
        textCopy = textCopy.replace(/(^\s*)|(\s*$)/gi, "");
        textCopy = textCopy.replace(/[ ]{2,}/gi, " ");
        textCopy = textCopy.replace(/\n /, "\n");
        //get all words of new string
        var wordsArr = textCopy.split(' ');
        //show the entire text if requested words is higher or equal to actual
        if (words >= wordsArr.length - 1)
            return this.text.length;
        //split array up to the number of words needed
        wordsArr = wordsArr.splice(0, words);
        //get the last word that will be showing
        var lastWordToShow = wordsArr[wordsArr.length - 1];
        //find the number of times that word is in the new array
        var occurencesOfLastWord = wordsArr.filter(function (str) { return str === lastWordToShow; }).length;
        //word only shows once so get the location in original text and add the length of the word
        if (occurencesOfLastWord == 1)
            return this.text.split(lastWordToShow)[0].length + lastWordToShow.length;
        //loop over each occurence of the last word and sum up characters
        var charactersUntilLastWord = 0;
        for (var i = 0; i < occurencesOfLastWord; i++) {
            charactersUntilLastWord += this.text.split(lastWordToShow)[i].length;
        }
        return charactersUntilLastWord + lastWordToShow.length;
    };
    TextExpander.decorators = [
        { type: core_1.Component, args: [{
                    selector: 'text-expander',
                    templateUrl: 'TextExpander.html'
                },] },
    ];
    /** @nocollapse */
    TextExpander.ctorParameters = [];
    TextExpander.propDecorators = {
        'expanded': [{ type: core_1.Input },],
        'ellipsis': [{ type: core_1.Input },],
        'text': [{ type: core_1.Input },],
        'characters': [{ type: core_1.Input },],
        'words': [{ type: core_1.Input },],
        'expandText': [{ type: core_1.Input },],
        'shrinkText': [{ type: core_1.Input },],
        'expandedChange': [{ type: core_1.Output },],
    };
    return TextExpander;
}());
exports.TextExpander = TextExpander;
var FuiTextExpanderModule = (function () {
    function FuiTextExpanderModule() {
    }
    FuiTextExpanderModule.decorators = [
        { type: core_1.NgModule, args: [{
                    imports: [common_1.CommonModule],
                    declarations: [TextExpander],
                    exports: [TextExpander]
                },] },
    ];
    /** @nocollapse */
    FuiTextExpanderModule.ctorParameters = [];
    return FuiTextExpanderModule;
}());
exports.FuiTextExpanderModule = FuiTextExpanderModule;
//# sourceMappingURL=TextExpander.js.map