"use strict";
var core_1 = require('@angular/core');
var common_1 = require("@angular/common");
var forms_1 = require("@angular/forms");
var TimePicker = (function () {
    function TimePicker() {
        this.hourStep = 1;
        this.minuteStep = 1;
        this.secondStep = 1;
        this.showMeridian = true;
        this.meridians = ["AM", "PM"];
        this.showSeconds = false;
        this.readonlyInput = false;
        this.showSpinners = true;
        this.disabled = false;
        this.min = new Date(new Date().getFullYear(), 0, 1, 0, 0, 0);
        this.max = new Date(new Date().getFullYear(), 0, 1, 23, 59, 59);
        this.value = new Date(new Date().getFullYear(), 0, 1, 0, 0, 0);
        this.meridian = this.meridians.length > 0 ? this.meridians[0] : null;
        this.hours = 0;
        this.minutes = "00";
        this.seconds = "00";
        this.invalidHours = false;
        this.invalidMinutes = false;
        this.invalidSeconds = false;
        this.valueChange = new core_1.EventEmitter();
    }
    TimePicker.prototype.ngOnInit = function () {
        this.hours = this.value.getHours();
        this.minutes = this.value.getMinutes() > 9 ? this.value.getMinutes().toString() : "0" + this.value.getMinutes().toString();
        this.seconds = this.value.getSeconds() > 9 ? this.value.getSeconds().toString() : "0" + this.value.getSeconds().toString();
        this.refresh();
    };
    TimePicker.prototype.ngOnChanges = function (changes) {
        this.refresh();
    };
    TimePicker.prototype.incrementHours = function () {
        if (!this.noIncrementHours()) {
            this.addSecondsToSelected(this.hourStep * 60 * 60);
        }
    };
    ;
    TimePicker.prototype.decrementHours = function () {
        if (!this.noDecrementHours()) {
            this.addSecondsToSelected(-this.hourStep * 60 * 60);
        }
    };
    ;
    TimePicker.prototype.incrementMinutes = function () {
        if (!this.noIncrementMinutes()) {
            this.addSecondsToSelected(this.minuteStep * 60);
        }
    };
    ;
    TimePicker.prototype.decrementMinutes = function () {
        if (!this.noDecrementMinutes()) {
            this.addSecondsToSelected(-this.minuteStep * 60);
        }
    };
    ;
    TimePicker.prototype.incrementSeconds = function () {
        if (!this.noIncrementSeconds()) {
            this.addSecondsToSelected(this.secondStep);
        }
    };
    ;
    TimePicker.prototype.decrementSeconds = function () {
        if (!this.noDecrementSeconds()) {
            this.addSecondsToSelected(-this.secondStep);
        }
    };
    ;
    TimePicker.prototype.toggleMeridian = function () {
        if (this.noToggleMeridian())
            return;
        if (this.minutes && this.hours) {
            this.addSecondsToSelected(12 * 60 * (this.value.getHours() < 12 ? 60 : -60));
        }
        else {
            this.meridian = this.meridian === this.meridians[0] ? this.meridians[1] : this.meridians[0];
        }
    };
    ;
    TimePicker.prototype.addSecondsToSelected = function (seconds) {
        this.value = this.addSeconds(this.value, seconds);
        this.hours = this.value.getHours();
        this.minutes = this.value.getMinutes() > 9 ? this.value.getMinutes().toString() : "0" + this.value.getMinutes().toString();
        this.seconds = this.value.getSeconds() > 9 ? this.value.getSeconds().toString() : "0" + this.value.getSeconds().toString();
        this.valueChange.next(this.value);
        this.sanitize();
        this.refresh();
    };
    TimePicker.prototype.addMinutes = function (selected, minutes) {
        return this.addSeconds(selected, minutes * 60);
    };
    TimePicker.prototype.addSeconds = function (date, seconds) {
        var dt = new Date(date.getTime() + seconds * 1000);
        var newDate = new Date(date.getTime());
        newDate.setHours(dt.getHours(), dt.getMinutes(), dt.getSeconds());
        return newDate;
    };
    TimePicker.prototype.invalidTime = function () {
        return this.invalidHours || this.invalidMinutes || this.invalidSeconds;
    };
    TimePicker.prototype.sanitize = function () {
        this.invalidHours = false;
        this.invalidMinutes = false;
        this.invalidSeconds = false;
    };
    TimePicker.prototype.refresh = function () {
        this.hours = this.value.getHours();
        this.minutes = this.value.getMinutes() > 9 ? this.value.getMinutes().toString() : "0" + this.value.getMinutes().toString();
        this.seconds = this.value.getSeconds() > 9 ? this.value.getSeconds().toString() : "0" + this.value.getSeconds().toString();
        if (this.hours >= 12 && this.showMeridian) {
            this.meridian = this.meridians[1];
        }
        if (this.showMeridian) {
            this.hours = this.hours === 0 || this.hours === 12 ? 12 : this.hours % 12; // Convert 24 to 12 hour system
        }
        this.meridian = this.value.getHours() < 12 ? this.meridians[0] : this.meridians[1];
    };
    TimePicker.prototype.updateHours = function () {
        this.sanitize();
        if (this.hours.toString().length <= 0 || isNaN(this.hours) || this.hours < 0 || this.hours > 23 || (this.showMeridian && this.hours > 12)) {
            this.invalidHours = true;
        }
        else {
            this.hours = parseInt(this.hours.toString());
            this.value.setHours(this.showMeridian && this.meridian == this.meridians[1] ? this.hours + 12 : this.hours);
            this.addSecondsToSelected(0);
        }
    };
    TimePicker.prototype.updateMinutes = function () {
        this.sanitize();
        if (this.minutes.length <= 0 || isNaN(parseInt(this.minutes)) || parseInt(this.minutes) < 0 || parseInt(this.minutes) > 59) {
            this.invalidMinutes = true;
        }
        else {
            this.value.setMinutes(parseInt(this.minutes));
            this.addSecondsToSelected(0);
        }
    };
    TimePicker.prototype.updateSeconds = function () {
        this.sanitize();
        if (this.seconds.length <= 0 || isNaN(parseInt(this.seconds)) || parseInt(this.seconds) < 0 || parseInt(this.seconds) > 59) {
            this.invalidSeconds = true;
        }
        else {
            this.value.setSeconds(parseInt(this.seconds));
            this.addSecondsToSelected(0);
        }
    };
    TimePicker.prototype.noIncrementHours = function () {
        var incrementedSelected = this.addMinutes(this.value, this.hourStep * 60);
        return this.disabled || incrementedSelected > this.max ||
            incrementedSelected < this.value && incrementedSelected < this.min;
    };
    ;
    TimePicker.prototype.noDecrementHours = function () {
        var decrementedSelected = this.addMinutes(this.value, -this.hourStep * 60);
        return this.disabled || decrementedSelected < this.min ||
            decrementedSelected > this.value && decrementedSelected > this.max;
    };
    ;
    TimePicker.prototype.noIncrementMinutes = function () {
        var incrementedSelected = this.addMinutes(this.value, this.minuteStep);
        return this.disabled || incrementedSelected > this.max ||
            incrementedSelected < this.value && incrementedSelected < this.min;
    };
    ;
    TimePicker.prototype.noDecrementMinutes = function () {
        var decrementedSelected = this.addMinutes(this.value, -this.minuteStep);
        return this.disabled || decrementedSelected < this.min ||
            decrementedSelected > this.value && decrementedSelected > this.max;
    };
    ;
    TimePicker.prototype.noIncrementSeconds = function () {
        var incrementedSelected = this.addSeconds(this.value, this.secondStep);
        return this.disabled || incrementedSelected > this.max ||
            incrementedSelected < this.value && incrementedSelected < this.min;
    };
    ;
    TimePicker.prototype.noDecrementSeconds = function () {
        var decrementedSelected = this.addSeconds(this.value, -this.secondStep);
        return this.disabled || decrementedSelected < this.min ||
            decrementedSelected > this.value && decrementedSelected > this.max;
    };
    ;
    TimePicker.prototype.noToggleMeridian = function () {
        if (this.value.getHours() < 12) {
            return this.disabled || this.addMinutes(this.value, 12 * 60) > this.max;
        }
        return this.disabled || this.addMinutes(this.value, -12 * 60) < this.min;
    };
    ;
    TimePicker.decorators = [
        { type: core_1.Component, args: [{
                    selector: "timepicker",
                    templateUrl: 'TimePicker.html',
                    styleUrls: ["TimePicker.css"]
                },] },
    ];
    /** @nocollapse */
    TimePicker.ctorParameters = [];
    TimePicker.propDecorators = {
        'hourStep': [{ type: core_1.Input },],
        'minuteStep': [{ type: core_1.Input },],
        'secondStep': [{ type: core_1.Input },],
        'showMeridian': [{ type: core_1.Input },],
        'meridians': [{ type: core_1.Input },],
        'showSeconds': [{ type: core_1.Input },],
        'readonlyInput': [{ type: core_1.Input },],
        'showSpinners': [{ type: core_1.Input },],
        'disabled': [{ type: core_1.Input },],
        'min': [{ type: core_1.Input },],
        'max': [{ type: core_1.Input },],
        'value': [{ type: core_1.Input },],
        'valueChange': [{ type: core_1.Output },],
    };
    return TimePicker;
}());
exports.TimePicker = TimePicker;
exports.TIMEPICKER_PROVIDERS = [
    TimePicker
];
var FuiTimePickerModule = (function () {
    function FuiTimePickerModule() {
    }
    FuiTimePickerModule.decorators = [
        { type: core_1.NgModule, args: [{
                    imports: [common_1.CommonModule, forms_1.FormsModule],
                    declarations: [TimePicker],
                    exports: [TimePicker]
                },] },
    ];
    /** @nocollapse */
    FuiTimePickerModule.ctorParameters = [];
    return FuiTimePickerModule;
}());
exports.FuiTimePickerModule = FuiTimePickerModule;
//# sourceMappingURL=TimePicker.js.map