"use strict";
var core_1 = require('@angular/core');
var Animation = (function () {
    function Animation(element) {
        this.onAnimationStart = new core_1.EventEmitter();
        this.onAnimationEnd = new core_1.EventEmitter();
        this.animationClasses = '';
        this.play = false;
        this.id = ''; // use for query filtering
        this.group = ''; // use for query filtering
        this._animationQueue = [];
        this._callbacks = [];
        this.element = element.nativeElement;
    }
    Animation.prototype.ngOnChanges = function (changes) {
        this.setup();
    };
    Animation.prototype.ngOnInit = function () {
        this.setup();
    };
    Animation.prototype.addAnimation = function (animationClasses) {
        var _this = this;
        animationClasses.split(' ')
            .map(function (c) { return _this._animationQueue.push(c); });
        this.animationClasses += " " + animationClasses;
        return this;
    };
    Animation.prototype.setup = function () {
        this._animationQueue = this.animationClasses
            .split(" ")
            .filter(function (c) { return c.length > 0; });
        if (this.play && this._animationQueue.length > 0)
            this.startAnimation();
        return this;
    };
    Animation.prototype.startAnimation = function (callback) {
        var _this = this;
        if (callback === void 0) { callback = null; }
        if (callback != null)
            this._callbacks.push(callback);
        this._animationQueue.shift()
            .split('.')
            .filter(function (c) { return c.length > 0; })
            .map(function (c) { return _this.element.classList.add(c); });
        return this;
    };
    Animation.prototype.cleanAnimation = function () {
        var _this = this;
        this.animationClasses
            .replace('.', ' ')
            .split(' ')
            .filter(function (c) { return c.length > 0; })
            .map(function (c) {
            _this.element.classList.remove(c);
        });
        return this;
    };
    Animation.prototype.animationStarted = function (event) {
        this.onAnimationStart.next(null);
    };
    Animation.prototype.animationEnded = function (event) {
        this.cleanAnimation();
        if (this._animationQueue.length > 0) {
            this.startAnimation();
            return;
        }
        while (this._callbacks.length > 0)
            this._callbacks.shift()();
        this.onAnimationEnd.next(null);
    };
    Animation.decorators = [
        { type: core_1.Directive, args: [{
                    selector: '[animation]',
                    host: {
                        '(animationstart)': 'animationStarted($event)',
                        '(webkitAnimationStart)': 'animationStarted($event)',
                        '(oanimationstart)': 'animationStarted($event)',
                        '(MSAnimationStart)': 'animationStarted($event)',
                        '(animationend)': 'animationEnded($event)',
                        '(webkitAnimationEnd)': 'animationEnded($event)',
                        '(oanimationend)': 'animationEnded($event)',
                        '(MSAnimationEnd)': 'animationEnded($event)'
                    }
                },] },
    ];
    /** @nocollapse */
    Animation.ctorParameters = [
        { type: core_1.ElementRef, },
    ];
    Animation.propDecorators = {
        'onAnimationStart': [{ type: core_1.Output },],
        'onAnimationEnd': [{ type: core_1.Output },],
        'animationClasses': [{ type: core_1.Input, args: ['animation',] },],
        'play': [{ type: core_1.Input },],
        'id': [{ type: core_1.Input },],
        'group': [{ type: core_1.Input },],
    };
    return Animation;
}());
exports.Animation = Animation;
var FuiAnimationModule = (function () {
    function FuiAnimationModule() {
    }
    FuiAnimationModule.decorators = [
        { type: core_1.NgModule, args: [{
                    declarations: [Animation],
                    exports: [Animation]
                },] },
    ];
    /** @nocollapse */
    FuiAnimationModule.ctorParameters = [];
    return FuiAnimationModule;
}());
exports.FuiAnimationModule = FuiAnimationModule;
//# sourceMappingURL=Animation.js.map