"use strict";
var core_1 = require('@angular/core');
var common_1 = require('@angular/common');
var Tooltip = (function () {
    function Tooltip(el) {
        this.text = '';
        this.position = 'top';
        this.color = 'none';
        this.size = 'auto';
        this.rounded = false;
        this.always = false;
        this._el = el.nativeElement;
    }
    Tooltip.prototype.ngOnInit = function () {
        if (this.always) {
            this._el.classList.add("hint--always");
            this.show();
        }
    };
    Tooltip.prototype.ngOnChanges = function (changes) {
        for (var i = 0; i < this._el.classList.length; i++) {
            var currentClass = this._el.classList[i];
            if (currentClass.startsWith("hint--"))
                this._el.classList.remove(currentClass);
        }
        if (this.always) {
            this._el.classList.add("hint--always");
            this.show();
        }
    };
    Tooltip.prototype.show = function () {
        if (!this.text || this.text.length == 0)
            return;
        this.hide();
        this._el.setAttribute("data-hint", this.text);
        for (var i = 0; i < this._el.classList.length; i++) {
            var currentClass = this._el.classList[i];
            if (currentClass.startsWith("hint"))
                this._el.classList.remove(currentClass);
        }
        if (this.always) {
            this._el.classList.add("hint--always");
        }
        this._el.classList.add("hint--" + this.position);
        switch (this.color) {
            case "error":
                this._el.classList.add("hint--error");
                break;
            case "warning":
                this._el.classList.add("hint--warning");
                break;
            case "info":
                this._el.classList.add("hint--info");
                break;
            case "success":
                this._el.classList.add("hint--success");
                break;
            default:
        }
        switch (this.size) {
            case "small":
                this._el.classList.add("hint--small");
                break;
            case "medium":
                this._el.classList.add("hint--medium");
                break;
            case "large":
                this._el.classList.add("hint--large");
                break;
            default:
        }
        if (this.rounded)
            this._el.classList.add("hint--rounded");
    };
    Tooltip.prototype.hide = function () {
        if (this.always)
            return;
        this._el.removeAttribute("data-hint");
    };
    Tooltip.decorators = [
        { type: core_1.Directive, args: [{
                    selector: '[tooltip]',
                    host: {
                        '(mouseover)': 'show()',
                        '(mouseout)': 'hide()',
                        '(focus)': 'show()',
                        '(unfocus)': 'hide()'
                    }
                },] },
    ];
    /** @nocollapse */
    Tooltip.ctorParameters = [
        { type: core_1.ElementRef, },
    ];
    Tooltip.propDecorators = {
        'text': [{ type: core_1.Input },],
        'position': [{ type: core_1.Input },],
        'color': [{ type: core_1.Input },],
        'size': [{ type: core_1.Input },],
        'rounded': [{ type: core_1.Input },],
        'always': [{ type: core_1.Input },],
    };
    return Tooltip;
}());
exports.Tooltip = Tooltip;
var FuiTooltipModule = (function () {
    function FuiTooltipModule() {
    }
    FuiTooltipModule.decorators = [
        { type: core_1.NgModule, args: [{
                    imports: [common_1.CommonModule],
                    declarations: [Tooltip],
                    exports: [Tooltip]
                },] },
    ];
    /** @nocollapse */
    FuiTooltipModule.ctorParameters = [];
    return FuiTooltipModule;
}());
exports.FuiTooltipModule = FuiTooltipModule;
//# sourceMappingURL=Tooltip.js.map