"use strict";
var core_1 = require('@angular/core');
var common_1 = require('@angular/common');
var StringUtils_1 = require('../../utilities/StringUtils');
var FormatPipe = (function () {
    function FormatPipe() {
        this.datePipe = new common_1.DatePipe("en-US");
        this.decimalPipe = new common_1.DecimalPipe("en-US");
    }
    FormatPipe.prototype.transform = function (input, args) {
        var format = '';
        var parsedFloat = 0;
        var pipeArgs = args.split(':');
        for (var i = 0; i < pipeArgs.length; i++) {
            pipeArgs[i] = pipeArgs[i].trim(' ');
        }
        //Escape all html if not explicitly set
        if (pipeArgs[0].toLowerCase() !== 'html')
            input = StringUtils_1.StringHelper.escapeHtml(input);
        switch (pipeArgs[0].toLowerCase()) {
            case 'text':
                return input;
            case 'decimal':
            case 'number':
                parsedFloat = !isNaN(parseFloat(input)) ? parseFloat(input) : 0;
                format = pipeArgs.length > 1 ? pipeArgs[1] : null;
                return this.decimalPipe.transform(parsedFloat, format);
            case 'percentage':
                parsedFloat = !isNaN(parseFloat(input)) ? parseFloat(input) : 0;
                format = pipeArgs.length > 1 ? pipeArgs[1] : null;
                return this.decimalPipe.transform(parsedFloat, format) + '%';
            case 'date':
            case 'datetime':
                var date = !isNaN(parseInt(input)) ? parseInt(input) : new Date(input);
                format = 'MMM d, y h:mm:ss a';
                if (pipeArgs.length > 1) {
                    format = '';
                    for (var i = 1; i < pipeArgs.length; i++) {
                        format += pipeArgs[i];
                    }
                }
                return this.datePipe.transform(date, format);
            default:
                return input;
        }
    };
    FormatPipe.decorators = [
        { type: core_1.Pipe, args: [{
                    name: 'format'
                },] },
    ];
    /** @nocollapse */
    FormatPipe.ctorParameters = [];
    return FormatPipe;
}());
exports.FormatPipe = FormatPipe;
var FuiFormatPipeModule = (function () {
    function FuiFormatPipeModule() {
    }
    FuiFormatPipeModule.decorators = [
        { type: core_1.NgModule, args: [{
                    imports: [common_1.CommonModule],
                    declarations: [FormatPipe],
                    exports: [FormatPipe]
                },] },
    ];
    /** @nocollapse */
    FuiFormatPipeModule.ctorParameters = [];
    return FuiFormatPipeModule;
}());
exports.FuiFormatPipeModule = FuiFormatPipeModule;
//# sourceMappingURL=Format.js.map