"use strict";
var moment = require("moment");
var DateUtils = (function () {
    function DateUtils() {
    }
    DateUtils.isValidDate = function (value) {
        return Object.prototype.toString.call(value) === "[object Date]"
            && !isNaN(value.valueOf()) && value.getTime() != 0;
    };
    DateUtils.handleDateInput = function (value) {
        if (DateUtils.isValidDate(value))
            return value;
        if (value instanceof moment)
            return value.toDate();
        if (typeof value !== "string")
            return null;
        // remove utf8 / encoding for ie (General Punctuation unicode)
        value = encodeURIComponent(value);
        value = value.replace(/%E2%80%8E/g, "");
        value = decodeURIComponent(value);
        if (!DateUtils.isDateFormat(value)) {
            return null;
        }
        return DateUtils.parseDate(value);
    };
    DateUtils.isDateFormat = function (value) {
        return DateUtils.isLocaleDateFormat(value) || DateUtils.isIsoDateFormat(value);
    };
    DateUtils.isLocaleDateFormat = function (value) {
        var ex = /^(\d{1,4})\/(\d{1,4})\/(\d{1,4})$/;
        return ex.exec(value) ? true : false;
    };
    DateUtils.isIsoDateFormat = function (value) {
        var dateExpressions = [];
        dateExpressions.push(/^(\d{4})-(\d{2})-(\d{2})T(\d{2})\:(\d{2})\:(\d{2})[+-](\d{2})\:(\d{2})$/);
        dateExpressions.push(/^(\d{4})-(\d{2})-(\d{2})T(\d{2}):(\d{2}):(\d{2})?$/);
        dateExpressions.push(/^\/Date\((d|-|.*)\)[\/|\\]$/);
        dateExpressions.push(/^(\d{4})-(\d{2})-(\d{2})T(\d{2}):(\d{2}):(\d{2}(?:\.\d*))(?:Z|(\+|-)([\d|:]*))?$/);
        for (var _i = 0, dateExpressions_1 = dateExpressions; _i < dateExpressions_1.length; _i++) {
            var exp = dateExpressions_1[_i];
            if (exp.exec(value))
                return true;
        }
        return false;
    };
    DateUtils.parseDate = function (value) {
        if (typeof value !== "string")
            return null;
        if (value.length > 30)
            return null;
        var date = null;
        if (DateUtils.isLocaleDateFormat(value)) {
            date = moment(value, DateUtils.getLocaleFormat());
        }
        if (DateUtils.isIsoDateFormat(value)) {
            date = moment(value);
        }
        if (date && date.isValid()) {
            return date.toDate();
        }
        return null;
    };
    DateUtils.formatDateForServer = function (date) {
        try {
            return date.getFullYear() + "/" + (date.getMonth() + 1) + "/" + date.getDate();
        }
        catch (err) {
            return "invalid date";
        }
    };
    DateUtils.getMonthName = function (month) {
        var monthNames = ["January", "February", "March", "April", "May", "June",
            "July", "August", "September", "October", "November", "December"
        ];
        return monthNames[month - 1];
    };
    DateUtils.addDaysToDate = function (date, numberOfDays) {
        date.setDate(date.getDate() + numberOfDays);
        return date;
    };
    DateUtils.getArrayOfDates = function (startDate, endDate) {
        var dates = [];
        var diffDays = Math.round(Math.abs((startDate.getTime() - endDate.getTime()) / (24 * 60 * 60 * 1000)));
        for (var i = 1; i <= diffDays; i++) {
            dates.push(this.addDaysToDate(new Date(startDate.toString()), i));
        }
        return dates;
    };
    DateUtils.getNumberOfNights = function (startDate, endDate) {
        return Math.round(Math.abs((startDate.getTime() - endDate.getTime()) / (24 * 60 * 60 * 1000)));
    };
    DateUtils.getLocaleFormat = function () {
        if (DateUtils.localeFormat.length == 0)
            DateUtils.localeFormat = DateUtils.generateLocaleFormat();
        return DateUtils.localeFormat;
    };
    DateUtils.generateLocaleFormat = function () {
        var lds = new Date(2016, 9, 25).toLocaleDateString();
        var yPosi = lds.search("2016");
        var dPosi = lds.search("25");
        var mPosi = lds.search("10");
        //Sometimes the month is displayed by the month name so guess where it is
        if (mPosi == -1) {
            mPosi = lds.search("9");
            if (mPosi == -1) {
                //if the year and day are not first then maybe month is first
                if (yPosi != 0 && dPosi != 0) {
                    mPosi = 0;
                }
                else if ((yPosi + 4 < lds.length) && (dPosi + 2 < lds.length)) {
                    mPosi = Infinity;
                }
                else if (yPosi < dPosi) {
                    mPosi = ((dPosi - yPosi) / 2) + yPosi;
                }
                else if (dPosi < yPosi) {
                    mPosi = ((yPosi - dPosi) / 2) + dPosi;
                }
            }
        }
        var formatString = "";
        var order = [yPosi, dPosi, mPosi];
        order.sort(function (a, b) { return a - b; });
        for (var i = 0; i < order.length; i++) {
            if (order[i] == yPosi) {
                formatString += "YYYY/";
            }
            else if (order[i] == dPosi) {
                formatString += "DD/";
            }
            else if (order[i] == mPosi) {
                formatString += "MM/";
            }
        }
        return formatString.substring(0, formatString.length - 1);
    };
    DateUtils.localeFormat = "";
    return DateUtils;
}());
exports.DateUtils = DateUtils;
//# sourceMappingURL=DateUtils.js.map